@@ -69,7 +69,7 @@ S = np.sum(np.conjugate(Vw)*Vw, axis=1).real*cev/(kbev*T)/Num_timesteps*dt_ps
 tot_area = np.trapz(S,freq)
 print(' The total DOS is ', tot_area*N)
 print(' You are losing ',N - tot_area*N, ' kBT')
-ZS[:,0] = freq[0:meta]
+ZS[:,0], ZS[:,1] = freq[0:meta], S[0:meta]
 
 Ctot = np.fft.ifft(S)
 for t in range(int(len(Ctot)/2)):
@@ -109,7 +109,7 @@ for i in range(Nqpoints):
     Qkw = np.fft.fft(Qkt, axis=0)
     Sq_proj = (np.conjugate(Qkw)*Qkw).real*cev/(kbev*T)/Num_timesteps*dt_ps
 
-
+    ZS[:,i+2] = Sq[0:meta]
     Zqs[:,0] = Sq[0:meta]
     Zqs[:,1:] = Sq_proj[0:meta,:]
     
