@@ -24,6 +24,8 @@ def figsize(scale):
 
 #import warnings
 #warnings.filterwarnings('ignore') 
+
+
 import matplotlib as mpl
 mpl.use('pgf')
 import matplotlib.pyplot as plt
@@ -70,22 +72,28 @@ def animate(frames,plot):
 #    plotOimag._offsets3d = (Oiimag[0::3],Oiimag[1::3],Oiimag[2::3])
     return
 
-def plot_eigvec(Ruc, n_uc, k,eigvec,freq, ax, fig):
+def plot_eigvec_ani(Ruc, n_uc, k,eigvec,freq, ax, fig, masses):
     t = np.arange(0,100,1)
     
     Rucxyz = np.repeat(Ruc,3,axis=0)
     EIGs = eigvec
     
-    exp1 = np.exp(1j*np.sum(np.multiply(k,Rucxyz),axis=1)) #this multiplies by the phase factor exp(i k.R)
+    centroid = np.sum(Ruc, axis=0)/len(Ruc[:,0])
+    L = np.sqrt(np.sum(Ruc**2))
+    
+    exp1 = np.cos(np.sum(np.multiply(k,Rucxyz),axis=1)) #this multiplies by the phase factor exp(i k.R)
     #exp2 = np.exp(1j*freq*t).reshape(1,len(t))
-    exp2 = np.sin(t).reshape(1,len(t))
+    exp2 = np.cos(t).reshape(1,len(t))
     EIG_exp = np.multiply(EIGs,exp1)
     ut = np.dot(EIG_exp.reshape(len(EIGs),1),exp2)
         
     Rt = Ruc.flatten().reshape(len(EIGs),1) + np.real(ut)
     Rt2 = Ruc.flatten().reshape(len(EIGs),1) + np.imag(ut)
+    
+    print(Rt[:,0])
 
-    plot = ax.scatter(Rt[0::3,0], Rt[1::3,0], Rt[2::3,0], s=100)
+    plot = ax.scatter(Rt[0::3,0], Rt[1::3,0], Rt[2::3,0], s=masses[0::3]*100)
+    ax.quiver(*centroid, *k*L, color='red')
     ani = animation.FuncAnimation(fig,animate,frames=Rt.T,fargs=(plot,))
     return ani
 
@@ -97,44 +105,94 @@ def plot(x,y,title):
     plt.show()
     return
 
-def plot_eigvec_noani(Ruc, n_uc, k,eigvec,freq, ax,fig):
-    t = np.arange(0,100,1)
-    
+def plot_eigvec_noani(Ruc, n_uc, k,eigvec,freq, ax,fig, masses):
+    eigvec = eigvec.real
+    centroid = np.sum(Ruc, axis=0)/len(Ruc[:,0])
     Rucxyz = np.repeat(Ruc,3,axis=0)
     
-    eigvec = eigvec.real
-    Ruc = Ruc.flatten()
+    L = np.sqrt(np.sum(Ruc**2))
     
-    ax.scatter(Ruc[0::3], Ruc[1::3], Ruc[2::3], alpha=0.5, s=100)
-    ax.quiver(Ruc[0::3], Ruc[1::3], Ruc[2::3], eigvec[0::3], eigvec[1::3], eigvec[2::3], color='black')
+    exp1 = np.cos(np.sum(np.multiply(k,Rucxyz),axis=1)) #this multiplies by the phase factor exp(i k.R)
+    EIG_exp = np.multiply(eigvec,exp1)
+    print('Displacement components:')
+    print(np.round(np.reshape(np.real(EIG_exp),np.shape(Ruc)),2))
+    print()
+    
+    Ruc = Ruc.flatten()
+
+    
+
+    ax.scatter(Ruc[0::3], Ruc[1::3], Ruc[2::3], alpha=0.3, s=masses[0::3]*100)
+    ax.quiver(Ruc[0::3], Ruc[1::3], Ruc[2::3], eigvec[0::3], eigvec[1::3], eigvec[2::3],  color='black', label='eigenvector')
+    ax.quiver(Ruc[0::3], Ruc[1::3], Ruc[2::3], EIG_exp[0::3], EIG_exp[1::3], EIG_exp[2::3],  color='blue', label='displacement')
+    ax.quiver(*centroid, *k*L, color='red', label='k vector')
+    ax.legend(fontsize='x-small')
+#    ax.set_xticks(np.arange(Ruc[0::3].max())), ax.set_yticks(np.arange(Ruc[1::3].max())), ax.set_zticks(np.arange(Ruc[2::3].max()))
+#    ax.set_xticks([]), ax.set_yticks([]), ax.set_zticks([])
+    plt.tight_layout()
     return 
 
-def plot_with_ani(x,y,ytot, k,eigvec,freq,n,Ruc,eigname,masses):
+def plot6(x,y,ytot, k,eigvec,freq,n,Ruc,eigname,masses, max_Z):
+    pgf_with_latex = {                      # setup matplotlib to use latex for output
+
+    "pgf.texsystem": "pdflatex",        # change this if using xetex or lautex
+
+    "text.usetex": True,                # use LaTeX to write all text
+
+    "font.family": "serif",
+
+    "font.serif": [],                   # blank entries should cause plots to inherit fonts from the document
+
+    "font.sans-serif": [],
+
+    "font.monospace": [],
+
+    "axes.labelsize": 16,                # LaTeX default is 10pt font.     "text.fontsize": 10,
+
+    "legend.fontsize": 'x-small',               # Make the legend/label fonts a little smaller
+
+    "xtick.labelsize": 16,
+
+    "ytick.labelsize": 16,
+
+    "figure.figsize": figsize(1.4),       # default fig size of 0.9 textwidth
+
+    "pgf.preamble": [
+
+        r"\usepackage[utf8x]{inputenc}",    # use utf8 fonts becasue your computer can handle it :)
+
+        r"\usepackage[T1]{fontenc}",        # plots will be generated using this preamble
+
+        ]
+
+    }
+    mpl.rcParams.update(pgf_with_latex)
+
+    
     fig,ax = plt.subplots()
-    graph2, = ax.plot(x,ytot,'--',label='total DOS', color='orangered')
+#    graph2, = ax.plot(x,ytot,'--',label='qpoint DOS', color='orangered')
     graph1, = ax.plot(x,y,label='mode-projected DOS', color='blue')
     ax.set_xlim(left=-1,right=30)
     ax.set_xlabel('Frequency [Thz]')
-    ax.set_title('Spectrum of mode n. '+str(n)+' kpoint '+str(k))
+    plt.title('Spectrum of mode n. '+str(n)+' kpoint '+str(np.round(k,2)))
     
-    ax1 = ax.twiny()
-    ax1.set_xlabel('Frequency [cm$^{-1}$]')
-    ax1.plot(x*33.35641,-np.ones(len(x)),c='white',linewidth=0,label='')
-    ax1.set_xlim(-1*33.35641,30*33.35641)
+#    ax1 = ax.twiny()
+#    ax1.set_xlabel('Frequency [cm$^{-1}$]')
+#    ax1.plot(x*33.35641,-np.ones(len(x)),c='white',linewidth=0,label='')
+#    ax1.set_xlim(-1*33.35641,30*33.35641)
 
     
-    
-    graph3, = ax.plot(np.repeat(freq,100),np.linspace(0,ytot.max(),100),':' ,c='r', label='freq from dispersion')
-    plt.legend(handles=[graph1, graph2, graph3], loc=2)
+    graph3, = ax.plot(np.repeat(freq,100),np.linspace(0,y.max(),100),':' ,c='r', label='freq from dispersion')
+    plt.legend(handles=[graph1,  graph3], loc=2)
     
     
-    ax2 = fig.add_axes([0.5, .5, .3, .3],projection='3d')
-    ax2.set_title(str(eigname)+'\nfrequency: '+str(freq))
+    
+    
+    ax2 = fig.add_axes([0.5, .5, .4, .4],projection='3d')
+#    ax2.set_title(str(eigname)+'\nfrequency: '+str(freq))
+    ax2.set_xlabel('x'), ax2.set_ylabel('y'), ax2.set_zlabel('z')
     ampl = 10
     eigvec = eigvec/np.sqrt(masses)*ampl
-    ani = plot_eigvec(Ruc, 1, [0,0,0],eigvec,freq,ax2,fig)
-    
-    
     print('Mode frequency: ', freq, '\n')
     print('Eigenvector components:')
     print(np.round(np.reshape(np.real(eigvec),np.shape(Ruc)),2))
@@ -142,8 +200,19 @@ def plot_with_ani(x,y,ytot, k,eigvec,freq,n,Ruc,eigname,masses):
     print('Imaginary part:')
     print(np.round(np.reshape(np.imag(eigvec),np.shape(Ruc)),2))
     print()
+    ani = plot_eigvec_noani(Ruc, 1,k,eigvec,freq,ax2,fig, masses)
     
+    
+    
+    
+    if(max_Z > np.max(ytot.max()) or max_Z < 0.0):
+        a=1
+    else:
+        ax.set_ylim(bottom=-max_Z/10,top=max_Z)
+        
     plt.show()
+    plt.tight_layout()
+    fig.savefig('plot6_'+str(np.round(k))+'_mode_'+str(n)+'.pdf')
     return ani
 
 def save_proj(x,y,ytot, k,Ruc, eigvec,freq,n,namedir,masses, params, max_Z):
@@ -711,13 +780,13 @@ def plot4(kk, frequencies, frequencies_disp, qpoints, x_labels, ZQS):
     
     ax2.plot(np.sum(ZQS[:,1:], axis=1), ZQS[:,0], label='DOS')
     ax2.set_xticks([])
-    ax2.tick_params(axis='y', which='major', labelsize=0.0001, width=2 , length=6, direction='in', top=True, right=True)
+    ax2.tick_params(axis='y', which='major', labelsize=0.001, width=2 , length=6, direction='in', top=True, right=True)
     
     
     plt.rcParams['axes.linewidth'] = 2
     ax.set_xticks(kk, x_labels)
     ax.legend(handles=[graph_disp, graph_ft])
-    ax2.legend()
+#    ax2.legend()
 #    plt.show()
     fig.savefig('plot4.pdf')
     return
