@@ -16,19 +16,21 @@ from decomp import plot, read
 input_file = sys.argv[1]
 plot_types = read.read_post_proc(input_file)[0]
 n_atom_unit_cell = read.read_post_proc(input_file)[1]
-file_eigenvectors = read.read_post_proc(input_file)[2]
-max_Z = read.read_post_proc(input_file)[3]
-freq_res = read.read_post_proc(input_file)[4]
-kinput = read.read_post_proc(input_file)[5::][0]
-labels = read.read_post_proc(input_file)[6]
-modes = read.read_post_proc(input_file)[7]
-temperatures_folders = read.read_post_proc(input_file)[8]
+Masses = read.read_post_proc(input_file)[2]
+file_eigenvectors = read.read_post_proc(input_file)[3]
+file_SPOSCAR = read.read_post_proc(input_file)[4]
+max_Z = read.read_post_proc(input_file)[5]
+freq_res = read.read_post_proc(input_file)[6]
+kinput = read.read_post_proc(input_file)[7::][0]
+labels = read.read_post_proc(input_file)[8]
+modes = read.read_post_proc(input_file)[9]
+temperatures_folders = read.read_post_proc(input_file)[10]
 
 
 
-Ruc, masses_for_animation = 0,0 #atm you dont plot eigenvectors
 tot_atoms_uc = int(np.sum(n_atom_unit_cell)) 
 Nqpoints, qpoints_scaled, ks, freqs_disp, eigvecs, distances, Hk = read.read_phonopy(file_eigenvectors, tot_atoms_uc)
+Ruc, R0, masses, masses_for_animation = read.read_SPOSCAR_and_masses(file_SPOSCAR, n_atom_unit_cell, n_atom_unit_cell, Masses)  
 #### =============================================================================
 
 for mode in plot_types:
@@ -205,7 +207,31 @@ for mode in plot_types:
     
         plot.plot_k2(freq,ZQS,ZQS_proj, x_labels,[freqs_from_disp],max_Z,modes, freq_res, title=['0K dispersion'])
 
-    
+    if(mode==6):
+        # take the path the user inputs and find all the k points you can plot
+        ks_path, x_labels, distances = read.read_path(kinput, Nqpoints, labels, Hk) #you use this only to get x_labels, you should include this into read_phonopy
+        num_modes = len(modes)
+        N_kpath = len(ks_path)
+        
+        freq = np.loadtxt('ZS', usecols=0)
+        meta = len(freq)
+        accepted_qpoints = []
+        for i in range(Nqpoints):
+            to_skip = (1+meta)*i
+            qpoint = np.genfromtxt('Zqs',skip_header=to_skip+0, max_rows=1)
+            for j in range(len(ks_path)):
+                if(np.allclose(qpoint, ks_path[j]) and ((qpoint.tolist() not in accepted_qpoints) or i==j)): #è un completo delirio
+                    accepted_qpoints.append(qpoint.tolist())
+                    eigvec = eigvecs[i]
+                    freq_disp = freqs_disp[i]
+                    Zq = np.genfromtxt('Zqs',skip_header=to_skip+1, max_rows=meta)
+                    for b in range(len(modes)):
+                        mm = modes[b]
+                        ani = plot.plot6(freq,Zq[:,mm+1],Zq[:,0], np.dot(Hk,qpoint),eigvec[:,mm],freq_disp[mm],mm,Ruc,file_eigenvectors,masses_for_animation, max_Z)
+        
+        
+        
+        
 
         
     
