@@ -77,25 +77,30 @@ def read_post_proc(input_file):
     ns = lista[2]
     n_atom_unit_cell = np.fromstring(ns, dtype=np.int, sep=',')
     
-    file_eigenvectors = str(lista[3])
+    m = lista[3]
+    Masses = np.fromstring(m, dtype=np.float, sep=',')
     
-    max_Z = float(lista[4])
+    file_eigenvectors = str(lista[4])
     
-    freq_res = float(lista[5])
+    file_SPOSCAR = lista[5]
     
-    ks = lista[6]
+    max_Z = float(lista[6])
+    
+    freq_res = float(lista[7])
+    
+    ks = lista[8]
     a = np.fromstring(ks, dtype=np.float, sep=',')
     num = len(a)/3
     kpoints = np.split(a,num)
     
-    labs = lista[7]
+    labs = lista[9]
     labels = labs.split(',')
     
-    modes = np.fromstring(lista[8], dtype=np.int, sep=',')
+    modes = np.fromstring(lista[10], dtype=np.int, sep=',')
     
-    temperature_folders = lista[9]
+    temperature_folders = lista[11]
     
-    return plot_types, n_atom_unit_cell, file_eigenvectors, max_Z, freq_res, kpoints, labels, modes, temperature_folders
+    return plot_types, n_atom_unit_cell, Masses, file_eigenvectors, file_SPOSCAR, max_Z, freq_res, kpoints, labels, modes, temperature_folders
 
 
 
@@ -192,26 +197,49 @@ def read_phonopy(file_eigenvectors, n_atom_unit_cell):
     return Nqpoints, qpoints_scaled, ks, frequencies, eigvecs, distances, Hk
 
 
-def read_SPOSCAR(file,N1N2N3,N,n_atom_conventional_cell,n_atom_primitive_cell):
+def read_SPOSCAR_and_masses(file, n_atom_conventional_cell,n_atom_primitive_cell, Masses):
     conv = np.genfromtxt(file, skip_header=1, max_rows=1)
     h = np.genfromtxt(file,skip_header=2, max_rows=3)
     S = np.genfromtxt(file, skip_header=8)
     
+    N = len(S[:,0])
+    tot_atoms_primitive = int(np.sum(n_atom_primitive_cell))
+    N1N2N3 = int(N/tot_atoms_primitive)
+    
     if (conv==1.0):
         conv_factor = 1.88973
     else:
         conv_factor = 1
             
-    tot_atoms_primitive = int(np.sum(n_atom_primitive_cell))
+    
     R0 = np.dot(h,S.T).T*conv_factor
     
     Ruc = np.zeros((tot_atoms_primitive,3))
     for i in range(len(n_atom_conventional_cell)):
         n = n_atom_conventional_cell[i]
         for j in range(n):
-            Ruc[i] = R0[i*j*N1N2N3]
+            Ruc[i] = R0[i*(j+1)*N1N2N3]
     R0 = np.repeat(R0,3,axis=0)
-    return Ruc, R0
+    
+    
+    repeated_masses = np.array([])
+    repeated_masses_for_ani = np.array([])
+    for i in range(len(Masses)):
+        mass = Masses[i]
+
+        n = n_atom_conventional_cell[i]
+        nprim = n_atom_primitive_cell[i]
+        
+        m = np.repeat(mass, N1N2N3*3*n)
+        m_ani = np.repeat(mass,nprim*3)
+        
+        repeated_masses = np.concatenate((repeated_masses,m))
+        repeated_masses_for_ani = np.concatenate((repeated_masses_for_ani,m_ani))
+        
+    masses = np.array(repeated_masses).flatten()
+    masses_for_animation = np.array(repeated_masses_for_ani).flatten()
+    
+    return Ruc, R0, masses, masses_for_animation
 
 def read_path(kinput_scaled, Nqpoints, labels, Hk):
     Nq_input = len(kinput_scaled)
